@@ -85,7 +85,9 @@ class Task(object):
         ]
         main_kwargs_to_display = self._get_kwargs_with_params_to_include(
             self._main_kwargs, params_to_display)
-        return '%s(%s)' % (self.__class__.__name__, main_kwargs_to_display)
+        return '%s(transfer_id=%s, %s)' % (
+            self.__class__.__name__, self._transfer_coordinator.transfer_id,
+            main_kwargs_to_display)
 
     @property
     def transfer_id(self):
@@ -238,6 +240,8 @@ class SubmissionTask(Task):
             to the _submit() method
         """
         try:
+            self._transfer_coordinator.set_status_to_queued()
+
             # Before submitting any tasks, run all of the on_queued callbacks
             on_queued_callbacks = get_callbacks(transfer_future, 'queued')
             for on_queued_callback in on_queued_callbacks:
